### Name: read.zoo
### Title: Reading and Writing zoo Series
### Aliases: read.zoo write.zoo
### Keywords: ts

### ** Examples

## Not run: 
##D ## turn *numeric* first column into yearmon index
##D ## where number is year + fraction of year represented by month
##D z <- read.zoo("foo.csv", sep = ",", FUN = as.yearmon)
##D 
##D ## first column is of form yyyy.mm
##D ## (Here we use format in place of as.character so that final zero 
##D ## is not dropped in dates like 2001.10 which as.character would do.)
##D f <- function(x) as.yearmon(format(x, nsmall = 2), "%Y.%m")
##D z <- read.zoo("foo.csv", header = TRUE, FUN = f)
##D 
##D ## turn *character* first column into "Date" index
##D ## Assume lines look like: 12/22/2007 1 2
##D z <- read.zoo("foo.tab", format = "%m/%d/%Y")
##D 
##D # Suppose lines look like: 09112007 1 2 and there is no header
##D z <- read.zoo("foo.txt", format = "%d%m%Y")
##D 
##D ## csv file with first column of form YYYY-mm-dd HH:MM:SS
##D ## Read in times as "chron" class. Requires chron 2.3-22 or later.
##D z <- read.zoo("foo.csv", header = TRUE, sep = ",", FUN = as.chron)
##D 
##D ## same but with custom format.  Note as.chron uses POSIXt-style 
##D ## Read in times as "chron" class. Requires chron 2.3-24 or later.
##D z <- read.zoo("foo.csv", header = TRUE, sep = ",", FUN = as.chron, 
##D         format = "
##D 
##D ## same file format but read it in times as "POSIXct" class.
##D z <- read.zoo("foo.csv", header = TRUE, sep = ",", tz = "")
##D 
##D ## csv file with first column mm-dd-yyyy. Read times as "Date" class.
##D z <- read.zoo("foo.csv", header = TRUE, sep = ",", format = "%m-%d-%Y")
##D 
##D ## whitespace separated file with first column of form YYYY-mm-ddTHH:MM:SS
##D ## and no headers.  T appears literally.  Requires chron 2.3-22 or later.
##D z <- read.zoo("foo.csv", FUN = as.chron)
## End(Not run)

## omit the read.table() phase and directly supply a data.frame
dat <- data.frame(date = paste("2000-01-", 10:15, sep = ""), a = rnorm(6), b = 1:6)
z <- read.zoo(dat)

## using built-in data frame BOD
read.zoo(BOD)

read.zoo(BOD, FUN = as.Date)

read.zoo(BOD[c(1:6, 1), ], aggregate = mean)




